==> commandlist-0.0.3.tar.gz: test/commandlist_test.dart <==
import 'package:test/test.dart';
import 'package:commandlist/commandlist.dart';
import 'package:command/command.dart';

main() {
  test("Iterator works as expected", () {
    var list = populatedList();

    int i = 1;
    for (var item in list) {
      expect(item, equals("Item $i"));
      i++;
    }
  });

  test("Empty list iterates correctly", () {
    var list = new CommandList();
    int i = 0;
    for (var item in list) {
      // ignore: unused_local_variable
      i++;
    }

    expect(i, equals(0));
  });

  test("Add item to end of the list", () {
    var list = new CommandList();
    var command = list.insert("Item 1");

    expect(command, equals(new isInstanceOf<Command>()));
    expect(command.key, equals("CommandList.Insert"));
    expect(list[0], equals("Item 1"));

    command.undo();
    expect(list.length, 0);

    command.execute();
    expect(list[0], equals("Item 1"));
  });

  test("Insert item in the middle of the list", () {
    var list = populatedList();

    var command = list.insert("I'm new here", index: 1);

    expect(command, equals(new isInstanceOf<Command>()));
    expect(list[1], equals("I'm new here"));

    command.undo();
    expect(list[1], equals("Item 2"));

    command.execute();
    expect(list[1], equals("I'm new here"));
  });

  test("Insert item outside of range", () {
    var list = populatedList();

    expect(() => list.insert("I'm new here", index: 5),
        throwsA(new isInstanceOf<RangeError>()));
  });

  test("Delete item", () {
    var list = populatedList();
    var item = list[1];

    var command = list.remove(item);
    expect(command.key, "CommandList.Remove");
    expect(list.length, equals(2));
    expect(list[0], equals("Item 1"));
    expect(list[1], equals("Item 3"));

    command.undo();
    expect(list.length, equals(3));
    expect(list[1], equals("Item 2"));

    command.execute();
    expect(list.length, equals(2));
    expect(list[0], equals("Item 1"));
    expect(list[1], equals("Item 3"));
  });

  test("Removing a non-existant item does not affect the list", () {
    var list = populatedList();
    var item = "I am not in the list";

    var command = list.remove(item);
    expect(list.length, equals(3));

    command.undo();
    expect(list.length, equals(3));

    command.execute();
    expect(list.length, equals(3));
  });

  test("Move an item to a new position", () {
    var list = populatedList();

    var command = list.moveItem(1, 2);
    expect(command.key, equals("CommandList.Move"));
    expect(list[0], "Item 1");
    expect(list[1], "Item 3");
    expect(list[2], "Item 2");

    command.undo();
    expect(list[0], "Item 1");
    expect(list[1], "Item 2");
    expect(list[2], "Item 3");

    command.execute();
    expect(list[0], "Item 1");
    expect(list[1], "Item 3");
    expect(list[2], "Item 2");
  });

  test("Move an item with an invalid index", () {
    var list = populatedList();
    expect(() => list.moveItem(5, 1), throwsA(new isInstanceOf<RangeError>()));
  });

  test("Move an item to an invalid index", () {
    var list = populatedList();
    expect(() => list.moveItem(1, 5), throwsA(new isInstanceOf<RangeError>()));
  });

  test("Get the index of an element", () {
    var list = populatedList();
    var item = list[1];

    var index = list.indexOf(item);
    expect(index, equals(1));
  });

  test("Getting the index of a non-existent element returns -1", () {
    var list = populatedList();
    var item = "la la la";
    var index = list.indexOf(item);
    expect(index, equals(-1));
  });

  test("Create list with custom tag", () {
    var list = new CommandList(tag: "Custom");

    var command = list.insert("Item 1");
    expect(command.key, equals("Custom.Insert"));

    command = list.moveItem(0, 0);
    expect(command.key, equals("Custom.Move"));

    command = list.remove(list[0]);
    expect(command.key, equals("Custom.Remove"));
  });

  test("Replace item with index setter",() {
    var list = populatedList();

    var command = list.replace(1, "New!");
    expect(command.key, equals("CommandList.Replace"));
    expect(list[1], equals("New!"));

    command.undo();
    expect(list[1], equals("Item 2"));

    command.execute();
    expect(list[1], equals("New!"));
  });
}

CommandList<String> populatedList() {
  return new CommandList<String>(source: [
    "Item 1",
    "Item 2",
    "Item 3",
  ]);
}

==> commandlist-0.0.6.tar.gz: test/commandlist_test.dart <==
import 'package:test/test.dart';
import 'package:commandlist/commandlist.dart';
import 'package:command/command.dart';

main() {
  test("Iterator works as expected", () {
    var list = populatedList();

    int i = 1;
    for (var item in list) {
      expect(item, equals("Item $i"));
      i++;
    }
  });

  test("Empty list iterates correctly", () {
    var list = new CommandList();
    int i = 0;
    for (var item in list) { // ignore: unused_local_variable
      i++;
    }

    expect(i, equals(0));
  });

  test("Add item to end of the list", () {
    var list = new CommandList();
    var command = list.insert("Item 1");

    expect(command, equals(new isInstanceOf<Command>()));
    expect(command.key, equals("CommandList.Insert"));
    expect(list[0], equals("Item 1"));

    command.undo();
    expect(list.length, 0);

    command.execute();
    expect(list[0], equals("Item 1"));
  });

  test("Insert item in the middle of the list", () {
    var list = populatedList();

    var command = list.insert("I'm new here", index: 1);

    expect(command, equals(new isInstanceOf<Command>()));
    expect(list[1], equals("I'm new here"));

    command.undo();
    expect(list[1], equals("Item 2"));

    command.execute();
    expect(list[1], equals("I'm new here"));
  });

  test("Insert item outside of range", () {
    var list = populatedList();

    expect(() => list.insert("I'm new here", index: 5),
        throwsA(new isInstanceOf<RangeError>()));
  });

  test("Delete item", () {
    var list = populatedList();
    var item = list[1];

    var command = list.remove(item);
    expect(command.key, "CommandList.Remove");
    expect(list.length, equals(2));
    expect(list[0], equals("Item 1"));
    expect(list[1], equals("Item 3"));

    command.undo();
    expect(list.length, equals(3));
    expect(list[1], equals("Item 2"));

    command.execute();
    expect(list.length, equals(2));
    expect(list[0], equals("Item 1"));
    expect(list[1], equals("Item 3"));
  });

  test("Removing a non-existant item does not affect the list", () {
    var list = populatedList();
    var item = "I am not in the list";

    var command = list.remove(item);
    expect(list.length, equals(3));

    command.undo();
    expect(list.length, equals(3));

    command.execute();
    expect(list.length, equals(3));
  });

  test("Move an item to a new position", () {
    var list = populatedList();

    var command = list.moveItem(1, 2);
    expect(command.key, equals("CommandList.Move"));
    expect(list[0], "Item 1");
    expect(list[1], "Item 3");
    expect(list[2], "Item 2");

    command.undo();
    expect(list[0], "Item 1");
    expect(list[1], "Item 2");
    expect(list[2], "Item 3");

    command.execute();
    expect(list[0], "Item 1");
    expect(list[1], "Item 3");
    expect(list[2], "Item 2");
  });

  test("Move an item with an invalid index", () {
    var list = populatedList();
    expect(() => list.moveItem(5, 1), throwsA(new isInstanceOf<RangeError>()));
  });

  test("Move an item to an invalid index", () {
    var list = populatedList();
    expect(() => list.moveItem(1, 5), throwsA(new isInstanceOf<RangeError>()));
  });

  test("Get the index of an element", () {
    var list = populatedList();
    var item = list[1];

    var index = list.indexOf(item);
    expect(index, equals(1));
  });

  test("Getting the index of a non-existent element returns -1", () {
    var list = populatedList();
    var item = "la la la";
    var index = list.indexOf(item);
    expect(index, equals(-1));
  });

  test("Create list with custom tag", () {
    var list = new CommandList(tag: "Custom");

    var command = list.insert("Item 1");
    expect(command.key, equals("Custom.Insert"));

    command = list.moveItem(0, 0);
    expect(command.key, equals("Custom.Move"));

    command = list.remove(list[0]);
    expect(command.key, equals("Custom.Remove"));
  });

  test("Replace item with index setter", () {
    var list = populatedList();

    var command = list.replace(1, "New!");
    expect(command.key, equals("CommandList.Replace"));
    expect(list[1], equals("New!"));

    command.undo();
    expect(list[1], equals("Item 2"));

    command.execute();
    expect(list[1], equals("New!"));
  });

  test("Do not auto-execute commands", () {
    var list = populatedList();
    var command = list.insert("Item 4", execute: false);

    expect(list.length, equals(3));
    expect(command.canExecute, isTrue);
    expect(command.canUndo, isFalse);

    command = list.remove("Item 3", execute: false);

    expect(list.length, equals(3));
    expect(command.canExecute, isTrue);
    expect(command.canUndo, isFalse);

    command = list.moveItem(0, 1, execute: false);

    expect(list[0], equals("Item 1"));
    expect(command.canExecute, isTrue);
    expect(command.canUndo, isFalse);

    command = list.replace(0, "Blah", execute: false);

    expect(list[0], equals("Item 1"));
    expect(command.canExecute, isTrue);
    expect(command.canUndo, isFalse);
  });

  test("Chain a child to insert", () {
    var list = populatedList();
    var command = list.insert("Item 4",
      child: list.remove("Item 1", execute: false),
    );

    expect(list[0], equals("Item 2"));
    expect(list[1], equals("Item 3"));
    expect(list[2], equals("Item 4"));

    command.undo();

    expect(list[0], equals("Item 1"));
    expect(list[1], equals("Item 2"));
    expect(list[2], equals("Item 3"));

    command.execute();

    expect(list[0], equals("Item 2"));
    expect(list[1], equals("Item 3"));
    expect(list[2], equals("Item 4"));
  });

  test("Chain a child to remove", () {
    var list = populatedList();
    var command = list.remove("Item 1",
      child: list.insert("Item 4", execute: false),
    );

    expect(list[0], equals("Item 2"));
    expect(list[1], equals("Item 3"));
    expect(list[2], equals("Item 4"));

    command.undo();

    expect(list[0], equals("Item 1"));
    expect(list[1], equals("Item 2"));
    expect(list[2], equals("Item 3"));

    command.execute();

    expect(list[0], equals("Item 2"));
    expect(list[1], equals("Item 3"));
    expect(list[2], equals("Item 4"));
  });

  test("Chain a child to move", () {
    var list = populatedList();
    var command = list.moveItem(0, 2,
      child: list.remove("Item 2", execute: false),
    );

    expect(list[0], equals("Item 3"));
    expect(list[1], equals("Item 1"));

    command.undo();

    expect(list[0], equals("Item 1"));
    expect(list[1], equals("Item 2"));
    expect(list[2], equals("Item 3"));

    command.execute();

    expect(list[0], equals("Item 3"));
    expect(list[1], equals("Item 1"));
  });

  test("Chain a child to replace", () {
    var list = populatedList();
    var command = list.replace(0, "Blah",
      child: list.remove("Item 2", execute: false),
    );

    expect(list[0], equals("Blah"));
    expect(list[1], equals("Item 3"));

    command.undo();

    expect(list[0], equals("Item 1"));
    expect(list[1], equals("Item 2"));
    expect(list[2], equals("Item 3"));

    command.execute();

    expect(list[0], equals("Blah"));
    expect(list[1], equals("Item 3"));
  });
}

    
CommandList<String> populatedList() {
  return new CommandList<String>(source: [
    "Item 1",
    "Item 2",
    "Item 3",
  ]);
}
